import type { TSESTree } from '../ts-estree';
export declare const LINEBREAK_MATCHER: RegExp;
/**
 * Determines whether two adjacent tokens are on the same line
 */
export declare function isTokenOnSameLine(left: TSESTree.Node | TSESTree.Token, right: TSESTree.Node | TSESTree.Token): boolean;
//# sourceMappingURL=misc.d.ts.map