"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RuleTester = void 0;
/* eslint-disable @typescript-eslint/no-deprecated */
const eslint_1 = require("eslint");
/**
 * @deprecated Use `@typescript-eslint/rule-tester` instead.
 */
class RuleTester extends eslint_1.RuleTester {
}
exports.RuleTester = RuleTester;
