export { FlatESLint } from './eslint/FlatESLint';
export { FlatESLint as ESLint } from './eslint/FlatESLint';
export { 
/**
 * @deprecated - use ESLint instead
 */
LegacyESLint, } from './eslint/LegacyESLint';
//# sourceMappingURL=ESLint.d.ts.map